@@ -1,15 +1,21 @@
 import base64
 import datetime
 from ..adapters.oracle import Oracle
-from .base import SQLRepresenter
+from .._compat import to_native, to_bytes
+from base64 import b64encode
+from .base import SQLRepresenter, JSONRepresenter
 from . import representers
 
 
 @representers.register_for(Oracle)
-class OracleRepresenter(SQLRepresenter):
+class OracleRepresenter(SQLRepresenter, JSONRepresenter):
     def exceptions(self, obj, field_type):
         if field_type == "blob":
-            obj = base64.b64encode(str(obj))
+            # ensure bytes-like before conversion
+            if type(obj) != bytes:
+                obj = to_bytes(obj)
+            obj = to_native(b64encode(obj))
+            # return "utl_raw.cast_to_raw('%s')" % obj
             return ":CLOB('%s')" % obj
         elif field_type == "date":
             if isinstance(obj, (datetime.date, datetime.datetime)):
